import java.io.FileNotFoundException;
import java.io.IOException;

import rstudio.*;

/* **************************************************************************
 * File:           RSA_Demo.java
 * First Created:  30.05.2006
 * Last Modified:  05.10.2006
 * Author and (C): Michael Hufschmidt
 * **************************************************************************
 * Content / Description / Requirements / Usage:
 *
 * This class instanciates a Remote Studio Applet which talks to an Instance
 * of a remote Task within Omnis Studio. 
 * **************************************************************************/
public class RSA_Demo {

  public static void main(String[] commandlineArgs) {
    System.out.println("Starting Java Main");
    RemoteST1 rs = new RemoteST1();
    if (rs == null) {
      System.out.println("Could not instanciate RSA_Demo\nExit Java Main");
      return;
    }
    String iniFileName = "rsa_demo.ini";
    // Example of an .ini file for reading Parameters
    /*
     ; Ini - File for Remote Studio Applet Demo
     ; Syntax: <Parameter> = <Value>
     ; Section names are in square brackets
     ; Parameters are case sensitive
     ; Lines starting with ";" and empty lines are ignored

     [RemoteStudio]
     WebServerURL = 127.0.0.1
     WebServerScript = /cgi-bin/nph-omniscgi.exe
     ; OmnisServer is optional if on the same PC
     OmnisServer =
     OmnisPort = 5912
     OmnisLibrary = RSA_DEMO
     OmnisClass = rtRemoteStudio
     */
    try {
      rs.loadParams(iniFileName);
    } catch (FileNotFoundException e) {
      System.out
          .println("Could not open " + iniFileName + "\nExit Java Main");
      return;
    } catch (IOException e) {
      System.out.println("IO problem with " + iniFileName
          + "\nExit Java Main");
      return;
    }

    int errorcode = rs.open(); // it looks as if errorcode is always = 0
    if (errorcode != 0) {
      String errortext = new String(rs.errorText());
      System.out.println("Could not open RSA_Demo, error code = " + errorcode
          + ", error text = " + errortext);
    }

    // now wait some time
    //    delay(1000);

    // select Method to call: This may be given as command line parameter
    String method = null;
    if (commandlineArgs.length >= 1) {
      method = commandlineArgs[0];
    } else {
      method = "rtnVarString"; // The default method
    }
    System.out.println("Calling RSA_Demo / Method " + method);

    // prepare Parameters
    int argCount = 2;
    RSvar[] args = new RSvar[argCount];
    String s = "The Hitchhiker's Guide to the Galaxy";
    args[0] = rs.newChar(s.toCharArray());
    args[1] = rs.newLong(42);

    // and now call a method in the Remote Task
    RSvar result = rs.execute(method, args, argCount);
    if (method.equals("rtnVarList")) {
      int cols = result.getColumnCount();
      int rows = result.getRowCount();
      for (int row = 0; row < rows; row++) {
        System.out.println("Row " + (row + 1) + ":");
        for (int col = 0; col < cols; col++) {
          RSvar field = result.getElement(row, col);
          String sField = new String(field.getChar());
          System.out.print("  Colunm " + (col + 1) + " = " + sField);
        }
        System.out.println();
      }
    } else {
      System.out.println(result.getChar());
    }
    rs.close();
    System.out.println("Exit Java Main");
    rs = null;
    return;
  }

  static void delay(int max) {
    // Does nothing, just simulates a long lasting database action
    String s0 = "12345678901234567890123456789012345678901234567890";
    StringBuffer s1 = new StringBuffer("");
    for (int i = 0; i < max; i++) {
      s1.append(s0);
      System.runFinalization();
      System.gc();
    }
  }
}
